<HTML>
<HEAD>
<TITLE>drawbridge.bdsltd.co.uk</TITLE>
<STYLE TYPE="text/css">
<!--
  body {
    background: white;
    color: black;
  }
  a {
    text-decoration: none;
    color: #9090ff;
  }
  .right {
    text-align: right;
  }
  .tiny {
    font-size: 8pt;
    font-family: sans-serif;
  }

-->
</STYLE>
</HEAD>
<BODY BGCOLOR=#ffffff TEXT=#000000>
<P ALIGN='CENTER'><TT><A HREF="/">HOME</A> :: <?php echo strftime("%c"); ?></TT></P>
<TABLE ALIGN=CENTER>
<TR>
<TD><FORM METHOD='post'><INPUT TYPE=hidden NAME=period VALUE='4'><INPUT TYPE='Submit' VALUE='4hrs'></FORM></TD>
<TD><FORM METHOD='post'><INPUT TYPE=hidden NAME=period VALUE='d'><INPUT TYPE='Submit' VALUE='Day'></FORM></TD>
<TD><FORM METHOD='post'><INPUT TYPE=hidden NAME=period VALUE='2d'><INPUT TYPE='Submit' VALUE='2 Days'></FORM></TD>
<TD><FORM METHOD='post'><INPUT TYPE=hidden NAME=period VALUE='w'><INPUT TYPE='Submit' VALUE='Week'></FORM></TD>
<TD><FORM METHOD='post'><INPUT TYPE=hidden NAME=period VALUE='m'><INPUT TYPE='Submit' VALUE='Month'></FORM></TD>
<TD><FORM METHOD='post'><INPUT TYPE=hidden NAME=period VALUE='y'><INPUT TYPE='Submit' VALUE='Year'></FORM></TD>
</TABLE>
<P ALIGN="CENTER">[ <B><?
    switch($period)
    {
      case '4':
        echo "last 4 hours";
	break;
      case 'd':
        echo "last day";
	break;
      case '2d':
        echo "last 2 days";
	break;
      case 'w':
        echo "last week";
	break;
      case 'm':
        echo "last month";
	break;
      case 'y':
        echo "last year";
	break;
      default:
        echo "last day";
    }
?></B> ]</P>
<P ALIGN='CENTER'><IMG SRC="graph.php3?t=b0&p=<?php echo $period; ?>" WIDTH=478 HEIGHT=172>
<IMG SRC="graph.php3?t=e0&p=<?php echo $period; ?>" WIDTH=478 HEIGHT=172></P>

<P ALIGN='CENTER'><IMG SRC="graph.php3?t=b1&p=<?php echo $period; ?>" WIDTH=478 HEIGHT=172>
<IMG SRC="graph.php3?t=e1&p=<?php echo $period; ?>" WIDTH=478 HEIGHT=172></P>

<P ALIGN='CENTER'><IMG SRC="graph.php3?t=w0&p=<?php echo $period; ?>" WIDTH=478 HEIGHT=172>
<IMG SRC="graph.php3?t=w1&p=<?php echo $period; ?>" WIDTH=478 HEIGHT=172></P>

<P ALIGN='CENTER'><IMG SRC="graph.php3?t=m&p=<?php echo $period; ?>" WIDTH=478 HEIGHT=172></P>

<P ALIGN='CENTER'><TT><?php passthru("uptime"); ?