#!/bin/sh
#
rrdtool                      \
  create network-eth1.rrd     \
    --start `date +%s`         \
    --step 300                  \
    DS:recv:COUNTER:600:U:U     \
    DS:tran:COUNTER:600:U:U     \
    DS:recverrs:COUNTER:600:U:U \
    DS:tranerrs:COUNTER:600:U:U \
    DS:trancoll:COUNTER:600:U:U \
    RRA:AVERAGE:0.5:1:600        \
    RRA:AVERAGE:0.5:6:700        \
    RRA:AVERAGE:0.5:24:775       \
    RRA:AVERAGE:0.5:288:3660     \
    RRA:MAX:0.5:1:600            \
    RRA:MAX:0.5:6:700            \
    RRA:MAX:0.5:24:775           \
    RRA:MAX:0.5:288:3660

