#!/bin/sh
#
rrdtool                    \
  create memory-free.rrd    \
    --start `date +%s`       \
    --step 300                \
    DS:realfree:GAUGE:1200:U:U \
    DS:swapfree:GAUGE:1200:U:U \
    DS:shared:GAUGE:1200:U:U   \
    DS:buffers:GAUGE:1200:U:U  \
    DS:cached:GAUGE:1200:U:U   \
    RRA:AVERAGE:0.5:1:600      \
    RRA:AVERAGE:0.5:6:700      \
    RRA:AVERAGE:0.5:24:775     \
    RRA:AVERAGE:0.5:288:3660   \
    RRA:MAX:0.5:1:600          \
    RRA:MAX:0.5:6:700          \
    RRA:MAX:0.5:24:775         \
    RRA:MAX:0.5:288:3660
